octo Package
============

:mod:`octo` Package
-------------------

.. automodule:: octo.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`exceptions` Module
------------------------

.. automodule:: octo.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`manager` Module
---------------------

.. automodule:: octo.manager
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`plugin` Module
--------------------

.. automodule:: octo.plugin
    :members:
    :undoc-members:
    :show-inheritance:

